==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Active</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation type="unfinished">同じバージョンがインストールされています</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+=</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This font will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Version</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">不明</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Basic info</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enable</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Export</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>deactivated</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation type="unfinished">不明</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Installed</source>
        <translation type="unfinished">インストール済み</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No search results</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Page down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add font</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Font info</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ja.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>すべて</translation>
    </message>
    <message>
        <source>System</source>
        <translation>システム</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ユーザー</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>お気に入り</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>有効</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>中国語</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>等幅フォント</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 はフォントファミリーです。続行すると、このフォントファミリー内のすべてのフォントが削除されます</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 はフォントファミリーです。続行すると、このフォントファミリー内のすべてのフォントが有効化されます</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 はフォントファミリーです。続行すると、このフォントファミリー内のすべてのフォントが無効化されます</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>有効化</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>無効化</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>選択されたすべてのフォントファミリーに適用</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ファイルが破損しています</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>既に同じバージョンがインストールされています</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>システムフォント</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 件のフォントがインストールされました</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 件のフォントがインストールされました</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>%1 件のフォントをインストールできませんでした。ディスク容量が不足しています。</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>%1 件のフォントをインストールできませんでした。ディスク容量が不足しています。</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>フォント</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>ファイルが破損しています</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>このフォントはアプリケーションで使用できなくなります</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>これらのフォントはアプリケーションで使用できなくなります</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>これ以外の%1 件のシステムフォントは削除されません</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>&quot;%1&quot;は使用中のため削除できません</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>これ以外の%1 件のシステムフォントと使用中のフォント&quot;%2&quot;は削除されません</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 件のフォントを削除しますか？</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>削除</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>フォントを削除しています。しばらくお待ちください...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>確認が必要です</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>フォントはインストールされませんでした</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>終了</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>続行</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>Don&apos;t let your dreams be dreams</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>基本情報</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>スタイル</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>タイプ</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>バージョン</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>詳細</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>完全な名前</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps name</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>トレードマーク</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>著作権表示</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>ライセンス情報</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>フォントマネージャー</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>フォントマネージャーは、フォントのインストールと管理を行うためのツールです。</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>フォントを読み込んでいます。しばらくお待ちください...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>フォントがデスクトップにエクスポートされました</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 件のフォントがデスクトップにエクスポートされました</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>1 件のフォントをエクスポートできませんでした。ディスク容量が不足しています。</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>%1 件のフォントをエクスポートできませんでした。ディスク容量が不足しています。</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>フォントを追加</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>有効化</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>無効化</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>お気に入り登録</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>お気に入り解除</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ファイルマネージャーで表示</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>エクスポート</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>無効化されました</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>フォントが無効化されました</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 は使用中のため、無効化できません</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>システムフォントと使用中のフォントは無効化できません</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>システムフォントは無効化できません</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>フォントをインストール</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>検証中...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>不明</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ファイルが破損しています</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>インストール済み</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>インストールされていません</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>フォントをインストール</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>検索</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>検索結果はありません</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>フォントがありません</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>ヘルプ</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>ショートカットを表示</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Page up</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Page down</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>削除</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>フォントを追加</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>お気に入り登録</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>お気に入り解除</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>フォントの情報</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>プレビューテキストを入力</translation>
    </message>
</context>
</TS>
